@@ -4,6 +4,7 @@ import json
 
 from elasticsearch.helpers import scan
 from future.utils import string_types
+from lighttree.exceptions import NotFoundNodeError
 
 from pandagg.connections import get_connection
 from pandagg.query import Bool
@@ -11,6 +12,7 @@ from pandagg.response import Response
 from pandagg.tree.mapping import Mapping
 from pandagg.tree.query.abstract import Query
 from pandagg.tree.aggs.aggs import Aggs
+from pandagg.utils import DSLMixin
 
 
 class Request(object):
@@ -94,7 +96,10 @@ class Request(object):
         return self._clone()
 
 
-class Search(Request):
+class Search(DSLMixin, Request):
+
+    _type_name = "search"
+
     def __init__(
         self,
         using=None,
@@ -229,6 +234,15 @@ class Search(Request):
             s._params["from"] = n.start or 0
             s._params["size"] = n.stop - (n.start or 0) if n.stop is not None else 10
             return s
+        elif isinstance(n, list):
+            # Columns selection
+            if self._mapping:
+                for key in n:
+                    try:
+                        self._mapping.get(key)
+                    except NotFoundNodeError:
+                        raise KeyError("%s not in index" % key)
+            return self.source(includes=n)
         else:  # This is an index lookup, equivalent to slicing by [n:n+1].
             # If negative index, abort.
             if n < 0:
@@ -595,9 +609,11 @@ class Search(Request):
             import pandas as pd  # noqa
         except ImportError:
             return ImportError("repr_auto_execute requires pandas dependency")
-        r = self.execute()
         if not self._aggs.is_empty():
+            # hits are not necessary to display aggregation results
+            r = self.size(0).execute()
             return r.aggregations.to_dataframe()
+        r = self.execute()
         return r.hits.to_dataframe()
 
     def __repr__(self):
