@@ -1,10 +1,11 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+from __future__ import unicode_literals
+
 from mock import patch
 
 from pandagg.node.query._parameter_clause import Must
-from pandagg.node.query.joining import Nested
 from pandagg.query import Query, Range, Prefix, Ids, Term, Terms, Nested
 from pandagg.node.query.term_level import Term as TermNode, Exists as ExistsNode
 from pandagg.node.query.joining import Nested as NestedNode
@@ -32,7 +33,7 @@ class QueryTestCase(PandaggTestCase):
             {"bool": {"boost": 2, "filter": [{"term": {"yolo": {"value": 2}}}]}},
         )
         self.assertEqual(
-            q.__str__(),
+            q.show(stdout=False),
             """<Query>
 bool, boost=2
 └── filter
@@ -263,9 +264,7 @@ bool, boost=2
         # ABOVE non-existing
         with self.assertRaises(ValueError) as e:
             initial_q.must(
-                {"term": {"new_field": 2}},
-                child="not_existing_node",
-                _name="somewhere",
+                {"term": {"new_field": 2}}, child="not_existing_node", _name="somewhere"
             )
         self.assertEqual(
             e.exception.args,
@@ -274,9 +273,7 @@ bool, boost=2
 
         with self.assertRaises(ValueError) as e:
             initial_q.must(
-                {"term": {"new_field": 2}},
-                child="not_existing_node",
-                _name="somewhere",
+                {"term": {"new_field": 2}}, child="not_existing_node", _name="somewhere"
             )
         self.assertEqual(
             e.exception.args,
@@ -431,7 +428,7 @@ bool, boost=2
     def test_must_at_root(self):
         q_i1 = Query()
         q1 = q_i1.must(
-            Term(field="some_field", value=2, _name="term_nid"), _name="bool_nid",
+            Term(field="some_field", value=2, _name="term_nid"), _name="bool_nid"
         )
         self.assertEqual(len(q_i1.list()), 0)
         bool_ = next((c for c in q1.list() if isinstance(c, BoolNode)))
@@ -441,7 +438,7 @@ bool, boost=2
         self.assertEqual(term.name, "term_nid")
 
         self.assertEqual(
-            q1.__str__(),
+            q1.show(stdout=False),
             """<Query>
 bool
 └── must
@@ -456,7 +453,7 @@ bool
         next((c for c in q2.list() if isinstance(c, Must)))
         next((c for c in q2.list() if isinstance(c, TermNode)))
         self.assertEqual(
-            q2.__str__(),
+            q2.show(stdout=False),
             """<Query>
 bool
 └── must
@@ -477,7 +474,7 @@ bool
         next((c for c in q3.list() if isinstance(c, TermNode)))
         next((c for c in q3.list() if isinstance(c, ExistsNode)))
         self.assertEqual(
-            q3.__str__(),
+            q3.show(stdout=False),
             """<Query>
 bool
 └── must
@@ -502,7 +499,7 @@ bool
         )
 
         self.assertEqual(
-            q.__str__(),
+            q.show(stdout=False),
             """<Query>
 bool
 ├── filter
@@ -693,7 +690,7 @@ bool
         )
         for r in (q1, q2):
             self.assertEqual(
-                r.__str__(),
+                r.show(stdout=False),
                 """<Query>
 bool
 └── must
@@ -707,7 +704,7 @@ bool
         q2 = q.query({"term": {"other_field": 3}})
         for r in (q1, q2):
             self.assertEqual(
-                r.__str__(),
+                r.show(stdout=False),
                 """<Query>
 bool
 └── must
@@ -722,7 +719,7 @@ bool
         q2 = q.query({"term": {"other_field": 3}})
         for r in (q1, q2):
             self.assertEqual(
-                r.__str__(),
+                r.show(stdout=False),
                 """<Query>
 bool
 └── must
@@ -737,9 +734,9 @@ bool
         q2 = q.query({"term": {"some_nested_path.id": 2}}, parent="root_nested")
         for r in (q1, q2):
             self.assertEqual(
-                r.__str__(),
+                r.show(stdout=False),
                 """<Query>
-nested, path="some_nested_path"
+nested, _name=root_nested, path="some_nested_path"
 └── query
     └── term, field=some_nested_path.id, value=2
 """,
@@ -750,7 +747,7 @@ nested, path="some_nested_path"
         q2 = q.query({"term": {"some_other_field": 2}}, parent="root_bool")
         for r in (q1, q2):
             self.assertEqual(
-                r.__str__(),
+                r.show(stdout=False),
                 """<Query>
 bool
 ├── filter
@@ -774,7 +771,7 @@ bool
         )
         for r in (q1, q2):
             self.assertEqual(
-                r.__str__(),
+                r.show(stdout=False),
                 """<Query>
 bool
 ├── filter
